#!/usr/bin/perl

#----------------------------------------------------------------------
#-- 
#-- Modulename:
#-- -----------
#--
#--    const_values.pm
#--   
#--
#-- Description:
#-- ------------
#--
#--    Some variables are definded here, that contain values which
#--    should stay easily modifiable for developers.
#--
#--
#-- Side-effects:
#-- -------------
#--
#--    All the exported variables are included global if a script
#--    requires this file.
#--
#--
#-- History:
#-- --------
#--
#--    07|08|1999 - Initial startup
#--    08|03|1999 - Added keywords PROGRAM and OPERATION-MODE
#--                 to @valid_config_keywords
#--    11|30|1999 - Added falcon_sbin_path to determine where the
#--                 proxy-programms are installed
#--
#----------------------------------------------------------------------

package const_values;

use Exporter ();
@ISA = qw(Exporter);
@EXPORT = qw($logfile $falcon_log_msg_pipe $cfgfile $global_section_name @valid_config_keywords $log_message_queue_key $message_queue_create $falcon_sbin_path $pid_file $message_queue_mode $max_message_length $false $true);

#-- Set the version for version checking.
$version = "08031999";

#-- The path, that falcon is installed under
$falcon_sbin_path = "/usr/local/falcon/sbin";

#-- Path and filename for the logfile. Where should it be stored an how is it named...
$logfile = "/var/log/falcon.log";

#-- The name of the file with the user-defined configuration data.
$cfgfile                   = "/usr/local/falcon/etc/falcon.cfg";

#-- The name of the file that the process-ids of the proxies are
#-- written to
$pid_file = "/var/run/falcon.pid";

#-- The string that identifies the global section in the configfile
#-- The global section is parsed for every plug, proxy or whatever.
$global_section_name       = "global-settings";

#-- A list of keywords that are valid for use in the $cfgfile.
@valid_config_keywords     = ("TIME-FRAME",
                              "RUN-WITH-UID",
                              "RUN-WITH-GID",
                              "DENY-HOST",
                              "PERMIT-HOST",
                              "CHROOT-PATH",
                              "LISTEN-INTERFACE",
                              "LISTEN-PORT",
                              "TARGET-HOST",
                              "TARGET-PORT",
                              "PROGRAM",
                              "OPERATION-MODE");

#-- ID of the message queue which belongs to our logging facility.
$log_message_queue_key = 6262930;

$message_queue_create = 0001000;
$message_queue_mode = 0422;
$max_message_length = 1024;


$false = 0;
$true = !$false;

1;