#!/usr/bin/perl

#----------------------------------------------------------------------
#-- 
#-- Filename:
#-- ---------
#--
#--    start_falcon.pl
#--   
#--
#-- Description:
#-- ------------
#--
#--    This is the central startup-program for falcon. It gets the 
#--    section-names from the configuration-file and starts the program
#--    that stands in the "program" entry of a section with that section-
#--    name as parameter.
#-- 
#--
#-- History:
#-- --------
#--
#--    11|30|1999 - Initial Startup
#--
#----------------------------------------------------------------------

use lib "/usr/local/falcon/lib/perl5";
use const_values;
use readcfg;

#-- get the section-names and write 'em to an array
@CFG_SECTIONS  = get_sections_from_cfgfile($cfgfile);

#-- If falcon was not properly stopped, delete the file that holds the
#-- pid of the old falcon-processes

if (-f $pid_file) {
   print "\nFalcon seems already to be running. If you're shure that it's not\n";
   print "please delete the file\n";
   print "$pid_file\n";
   print "and try starting Falcon again.\n\n";
   exit;
}

#unlink $pid_file;

#-- Turn buffering off for STDOUT
$|=1;

#-- Start the logging-facility
print "Starting falconlogd... ";
$rc = system("$falcon_sbin_path/falconlogd.pl -d");
print "done.\n";

#-- For each section start the program thats given in the sections
#-- "program"-entry
foreach my $section (@CFG_SECTIONS)
{
   my %CONFIG_VALUES  = readcfg($section);
   my $program        = $CONFIG_VALUES{"PROGRAM"};
#   my $operation_mode = $CONFIG_VALUES{"OPERATION-MODE"};
   print "Starting $program with section $section... ";

   $rc = system("$falcon_sbin_path/$program -s $section");
   print "done.\n";
}

#----------------------------------------------------------------------
#-- 
#-- Subroutinename:
#-- ---------------
#--
#--    get_sections_from_cfgfile
#--   
#--
#-- Description:
#-- ------------
#--
#--    Reads the configuration-file which name is given as parameter
#--    It returns an array with the names of all sections that the
#--    file includes except the global-section.
#--
#-- 
#-- Arguments:
#-- ----------
#--
#--    In:
#--       scalar filename_of_configfile
#--
#--    In-Out:
#--       None
#--
#--    Out:
#--       array section_names
#--
#--
#-- 
#-- Side-effects:
#-- -------------
#--
#--    If an unknown keyword is found in the configfile, the program
#--    aborts. Thus typos can be prevented.
#--
#----------------------------------------------------------------------
sub get_sections_from_cfgfile
{
   my $cfgfile  = shift;
   my @SECTIONS = ();
   open (CFGFILE,"<$cfgfile") or die "Could not open configuration-file: $!\n";
   my @CFGLINES = <CFGFILE>;
   close (CFGFILE);
   foreach my $line (@CFGLINES) {
      #-- RegEx to extract the name of a section from a line that
      #-- includes the string "section"
      if ($line =~ /^\s*section\s*(.*)\s*\:/) {
         if ($1 ne $global_section_name) {
            push @SECTIONS, $1;
         }
      }
   }
   return @SECTIONS;
}